==> snipe-it-7.1.17.zip: snipe-it-7.1.17/resources/lang/ja-JP/admin/custom_fields/general.php <==
<?php

return [
    'custom_fields'		        => 'カスタムフィールド',
    'manage'                    => '管理',
    'field'		                => 'フィールド',
    'about_fieldsets_title'		=> 'フィールドセットについて',
    'about_fieldsets_text'		=> 'フィールドセットでは、特定の資産モデルタイプで頻繁に再利用されるカスタムフィールドのグループを作成することができます。',
    'custom_format'             => 'カスタム正規表現形式…',
    'encrypt_field'      	        => 'このフィールドの値をデータベースにて暗号化する',
    'encrypt_field_help'      => '警告: 暗号化フィールドは検索することができなくなります。',
    'encrypted'      	        => '暗号化',
    'fieldset'      	        => 'フィールドセット',
    'qty_fields'      	      => '数量フィールド',
    'fieldsets'      	        => 'フィールドセット',
    'fieldset_name'           => 'フィールドセット名',
    'field_name'              => 'フィールド名',
    'field_values'            => 'フィールド値',
    'field_values_help'       => '選択可能なオプションを1行に1つ追加します。最初の行以外の空白行は無視されます。',
    'field_element'           => 'フォームエレメント',
    'field_element_short'     => 'エレメント',
    'field_format'            => 'フォーマット',
    'field_custom_format'     => 'カスタム形式：',
    'field_custom_format_help'     => 'このフィールドでは、検証のために正規表現を使用できます。たとえば、カスタムフィールド値に有効なIMEI（15桁）が含まれていることを検証するには、<code>regex：/ ^ [0-9]{15} $ / </code>を使用します。',
    'required'   		          => '必須',
    'req'   		              => '必須',
    'used_by_models'   		    => '型番で使用',
    'order'   		            => '順番',
    'create_fieldset'         => '新しいフィールドセット',
    'update_fieldset'         => 'フィールドセットを更新',
    'fieldset_does_not_exist'   => 'フィールドセット:idが存在しません',
    'fieldset_updated'         => 'フィールドセットが更新されました',
    'create_fieldset_title' => '新しいフィールドセットを作成',
    'create_field'            => '新しいユーザー設定フィールド',
    'create_field_title' => '新しいカスタムフィールドを作成',
    'value_encrypted'      	        => 'このフィールドの値は、データベースで暗号化されます。管理者ユーザーのみが復号化された値を表示することができます。',
    'show_in_email'     => 'このフィールドの値をユーザーに送信されたチェックアウトメールに含めますか？暗号化されたフィールドはメールに含めることはできません',
    'show_in_email_short'     => '電子メールに含める。',
    'help_text' => 'ヘルプ テキスト',
    'help_text_description' => 'このテキストは、資産の編集中にフォーム要素の下に表示されるオプションのテキストです。',
    'about_custom_fields_title' => 'カスタムフィールドについて',
    'about_custom_fields_text' => 'カスタムフィールドでは、任意の属性を資産に追加できます。',
    'add_field_to_fieldset' => 'フィールドセットにフィールドを追加',
    'make_optional' => '必須 - クリックでオプションに変更',
    'make_required' => 'オプション - クリックで必須にします',
    'reorder' => '並べ替え',
    'db_field' => 'DBフィールド',
    'db_convert_warning' => '警告。このフィールドは <code>:db_column</code> としてカスタムフィールドテーブルにありますが、 <code>:expected</code> でなければなりません。',
    'is_unique' => 'この値はすべての資産で一意である必要があります',
    'unique' => '一意',
    'display_in_user_view' => 'チェックアウトされたユーザーが割り当てられたアセットを表示ページでこれらの値を表示できるようにします',
    'display_in_user_view_table' => 'ユーザーに表示',
    'auto_add_to_fieldsets' => '新しいフィールドセットに自動的に追加する',
    'add_to_preexisting_fieldsets' => '既存のフィールドセットに追加',
    'show_in_listview' => 'リストビューにデフォルトで表示します。承認されたユーザーは、列セレクターで表示/非表示を切り替えることができます。',
    'show_in_listview_short' => 'リストに表示',
    'show_in_requestable_list_short' => '要求可能なアセットリストに表示',
    'show_in_requestable_list' => '要求可能なアセットリストに値を表示します。暗号化されたフィールドは表示されません',
    'encrypted_options' => 'このフィールドは暗号化されているため、いくつかの表示オプションは利用できません。',

];

==> snipe-it-8.0.1.zip: snipe-it-8.0.1/resources/lang/ja-JP/admin/custom_fields/general.php <==
<?php

return [
    'custom_fields'		        => 'カスタムフィールド',
    'manage'                    => '管理',
    'field'		                => 'フィールド',
    'about_fieldsets_title'		=> 'フィールドセットについて',
    'about_fieldsets_text'		=> 'フィールドセットでは、特定の資産モデルタイプで頻繁に再利用されるカスタムフィールドのグループを作成することができます。',
    'custom_format'             => 'カスタム正規表現形式…',
    'encrypt_field'      	        => 'このフィールドの値をデータベースにて暗号化する',
    'encrypt_field_help'      => '警告: 暗号化フィールドは検索することができなくなります。',
    'encrypted'      	        => '暗号化',
    'fieldset'      	        => 'フィールドセット',
    'qty_fields'      	      => '数量フィールド',
    'fieldsets'      	        => 'フィールドセット',
    'fieldset_name'           => 'フィールドセット名',
    'field_name'              => 'フィールド名',
    'field_values'            => 'フィールド値',
    'field_values_help'       => '選択可能なオプションを1行に1つ追加します。最初の行以外の空白行は無視されます。',
    'field_element'           => 'フォームエレメント',
    'field_element_short'     => 'エレメント',
    'field_format'            => 'フォーマット',
    'field_custom_format'     => 'カスタム形式：',
    'field_custom_format_help'     => 'このフィールドでは、検証のために正規表現を使用できます。たとえば、カスタムフィールド値に有効なIMEI（15桁）が含まれていることを検証するには、<code>regex：/ ^ [0-9]{15} $ / </code>を使用します。',
    'required'   		          => '必須',
    'req'   		              => '必須',
    'used_by_models'   		    => '型番で使用',
    'order'   		            => '順番',
    'create_fieldset'         => '新しいフィールドセット',
    'update_fieldset'         => 'フィールドセットを更新',
    'fieldset_does_not_exist'   => 'フィールドセット:idが存在しません',
    'fieldset_updated'         => 'フィールドセットが更新されました',
    'create_fieldset_title' => '新しいフィールドセットを作成',
    'create_field'            => '新しいユーザー設定フィールド',
    'create_field_title' => '新しいカスタムフィールドを作成',
    'value_encrypted'      	        => 'このフィールドの値は、データベースで暗号化されます。管理者ユーザーのみが復号化された値を表示することができます。',
    'show_in_email'     => 'このフィールドの値をユーザーに送信されたチェックアウトメールに含めますか？暗号化されたフィールドはメールに含めることはできません',
    'show_in_email_short' => 'Include in emails',
    'help_text' => 'ヘルプ テキスト',
    'help_text_description' => 'このテキストは、資産の編集中にフォーム要素の下に表示されるオプションのテキストです。',
    'about_custom_fields_title' => 'カスタムフィールドについて',
    'about_custom_fields_text' => 'カスタムフィールドでは、任意の属性を資産に追加できます。',
    'add_field_to_fieldset' => 'フィールドセットにフィールドを追加',
    'make_optional' => '必須 - クリックでオプションに変更',
    'make_required' => 'オプション - クリックで必須にします',
    'reorder' => '並べ替え',
    'db_field' => 'DBフィールド',
    'db_convert_warning' => '警告。このフィールドは <code>:db_column</code> としてカスタムフィールドテーブルにありますが、 <code>:expected</code> でなければなりません。',
    'is_unique' => 'この値はすべての資産で一意である必要があります',
    'unique' => '一意',
    'display_in_user_view' => 'チェックアウトされたユーザーが割り当てられたアセットを表示ページでこれらの値を表示できるようにします',
    'display_in_user_view_table' => 'ユーザーに表示',
    'auto_add_to_fieldsets' => '新しいフィールドセットに自動的に追加する',
    'add_to_preexisting_fieldsets' => '既存のフィールドセットに追加',
    'show_in_listview' => 'リストビューにデフォルトで表示します。承認されたユーザーは、列セレクターで表示/非表示を切り替えることができます。',
    'show_in_listview_short' => 'リストに表示',
    'show_in_requestable_list_short' => '要求可能なアセットリストに表示',
    'show_in_requestable_list' => '要求可能なアセットリストに値を表示します。暗号化されたフィールドは表示されません',
    'encrypted_options' => 'このフィールドは暗号化されているため、いくつかの表示オプションは利用できません。',
    'display_checkin' => 'Display in checkin forms',
    'display_checkout' => 'Display in checkout forms',

];
